@@ -2,6 +2,9 @@ package WWW::GitHub::Repo;
 
 use WWW::API;
 
+with 'WWW::API::Role::Encoder::WWWFormURLEncoded';
+with 'WWW::API::Role::Decoder::JSON';
+
 define_api 'https://api.github.com';
 
 get_api 'repo',  '/repos/:user/:repo';
